==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/Brand.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DefaultApp;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Brand
 */
@JsonPropertyOrder({ Brand.JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY, Brand.JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL,
        Brand.JSON_PROPERTY_DEFAULT_APP, Brand.JSON_PROPERTY_EMAIL_DOMAIN_ID, Brand.JSON_PROPERTY_ID,
        Brand.JSON_PROPERTY_IS_DEFAULT, Brand.JSON_PROPERTY_LOCALE, Brand.JSON_PROPERTY_NAME,
        Brand.JSON_PROPERTY_REMOVE_POWERED_BY_OKTA })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class Brand implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY = "agreeToCustomPrivacyPolicy";
    private Boolean agreeToCustomPrivacyPolicy;

    public static final String JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL = "customPrivacyPolicyUrl";
    private String customPrivacyPolicyUrl;

    public static final String JSON_PROPERTY_DEFAULT_APP = "defaultApp";
    private DefaultApp defaultApp;

    public static final String JSON_PROPERTY_EMAIL_DOMAIN_ID = "emailDomainId";
    private String emailDomainId;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_IS_DEFAULT = "isDefault";
    private Boolean isDefault;

    public static final String JSON_PROPERTY_LOCALE = "locale";
    private String locale;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_REMOVE_POWERED_BY_OKTA = "removePoweredByOkta";
    private Boolean removePoweredByOkta = false;

    public Brand() {
    }

    /*
     * @JsonCreator public Brand(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_IS_DEFAULT) Boolean isDefault ) { this(); this.id = id; this.isDefault = isDefault; }
     */

    public Brand agreeToCustomPrivacyPolicy(Boolean agreeToCustomPrivacyPolicy) {

        this.agreeToCustomPrivacyPolicy = agreeToCustomPrivacyPolicy;
        return this;
    }

    /**
     * Consent for updating the custom privacy URL. Not required when resetting the URL.
     *
     * @return agreeToCustomPrivacyPolicy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Consent for updating the custom privacy URL. Not required when resetting the URL.")
    @JsonProperty(JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getAgreeToCustomPrivacyPolicy() {
        return agreeToCustomPrivacyPolicy;
    }

    @JsonProperty(JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAgreeToCustomPrivacyPolicy(Boolean agreeToCustomPrivacyPolicy) {
        this.agreeToCustomPrivacyPolicy = agreeToCustomPrivacyPolicy;
    }

    public Brand customPrivacyPolicyUrl(String customPrivacyPolicyUrl) {

        this.customPrivacyPolicyUrl = customPrivacyPolicyUrl;
        return this;
    }

    /**
     * Custom privacy policy URL
     *
     * @return customPrivacyPolicyUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Custom privacy policy URL")
    @JsonProperty(JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCustomPrivacyPolicyUrl() {
        return customPrivacyPolicyUrl;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomPrivacyPolicyUrl(String customPrivacyPolicyUrl) {
        this.customPrivacyPolicyUrl = customPrivacyPolicyUrl;
    }

    public Brand defaultApp(DefaultApp defaultApp) {

        this.defaultApp = defaultApp;
        return this;
    }

    /**
     * Get defaultApp
     *
     * @return defaultApp
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DefaultApp getDefaultApp() {
        return defaultApp;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefaultApp(DefaultApp defaultApp) {
        this.defaultApp = defaultApp;
    }

    public Brand emailDomainId(String emailDomainId) {

        this.emailDomainId = emailDomainId;
        return this;
    }

    /**
     * The ID of the email domain
     *
     * @return emailDomainId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID of the email domain")
    @JsonProperty(JSON_PROPERTY_EMAIL_DOMAIN_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEmailDomainId() {
        return emailDomainId;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_DOMAIN_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailDomainId(String emailDomainId) {
        this.emailDomainId = emailDomainId;
    }

    /**
     * The Brand ID
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The Brand ID")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * If &#x60;true&#x60;, the Brand is used for the Okta subdomain
     *
     * @return isDefault
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "If `true`, the Brand is used for the Okta subdomain")
    @JsonProperty(JSON_PROPERTY_IS_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getIsDefault() {
        return isDefault;
    }

    public Brand locale(String locale) {

        this.locale = locale;
        return this;
    }

    /**
     * The language specified as an [IETF BCP 47 language tag](https://datatracker.ietf.org/doc/html/rfc5646)
     *
     * @return locale
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The language specified as an [IETF BCP 47 language tag](https://datatracker.ietf.org/doc/html/rfc5646)")
    @JsonProperty(JSON_PROPERTY_LOCALE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLocale() {
        return locale;
    }

    @JsonProperty(JSON_PROPERTY_LOCALE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLocale(String locale) {
        this.locale = locale;
    }

    public Brand name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of the Brand
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of the Brand")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public Brand removePoweredByOkta(Boolean removePoweredByOkta) {

        this.removePoweredByOkta = removePoweredByOkta;
        return this;
    }

    /**
     * Removes \&quot;Powered by Okta\&quot; from the sign-in page in redirect authentication deployments, and \&quot;©
     * [current year] Okta, Inc.\&quot; from the Okta End-User Dashboard
     *
     * @return removePoweredByOkta
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Removes \"Powered by Okta\" from the sign-in page in redirect authentication deployments, and \"© [current year] Okta, Inc.\" from the Okta End-User Dashboard")
    @JsonProperty(JSON_PROPERTY_REMOVE_POWERED_BY_OKTA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRemovePoweredByOkta() {
        return removePoweredByOkta;
    }

    @JsonProperty(JSON_PROPERTY_REMOVE_POWERED_BY_OKTA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRemovePoweredByOkta(Boolean removePoweredByOkta) {
        this.removePoweredByOkta = removePoweredByOkta;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Brand brand = (Brand) o;
        return Objects.equals(this.agreeToCustomPrivacyPolicy, brand.agreeToCustomPrivacyPolicy)
                && Objects.equals(this.customPrivacyPolicyUrl, brand.customPrivacyPolicyUrl)
                && Objects.equals(this.defaultApp, brand.defaultApp)
                && Objects.equals(this.emailDomainId, brand.emailDomainId) && Objects.equals(this.id, brand.id)
                && Objects.equals(this.isDefault, brand.isDefault) && Objects.equals(this.locale, brand.locale)
                && Objects.equals(this.name, brand.name)
                && Objects.equals(this.removePoweredByOkta, brand.removePoweredByOkta);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(agreeToCustomPrivacyPolicy, customPrivacyPolicyUrl, defaultApp, emailDomainId, id,
                isDefault, locale, name, removePoweredByOkta);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Brand {\n");
        sb.append("    agreeToCustomPrivacyPolicy: ").append(toIndentedString(agreeToCustomPrivacyPolicy)).append("\n");
        sb.append("    customPrivacyPolicyUrl: ").append(toIndentedString(customPrivacyPolicyUrl)).append("\n");
        sb.append("    defaultApp: ").append(toIndentedString(defaultApp)).append("\n");
        sb.append("    emailDomainId: ").append(toIndentedString(emailDomainId)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    isDefault: ").append(toIndentedString(isDefault)).append("\n");
        sb.append("    locale: ").append(toIndentedString(locale)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    removePoweredByOkta: ").append(toIndentedString(removePoweredByOkta)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/Brand.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DefaultApp;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Brand
 */
@JsonPropertyOrder({ Brand.JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY, Brand.JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL,
        Brand.JSON_PROPERTY_DEFAULT_APP, Brand.JSON_PROPERTY_EMAIL_DOMAIN_ID, Brand.JSON_PROPERTY_ID,
        Brand.JSON_PROPERTY_IS_DEFAULT, Brand.JSON_PROPERTY_LOCALE, Brand.JSON_PROPERTY_NAME,
        Brand.JSON_PROPERTY_REMOVE_POWERED_BY_OKTA })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class Brand implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY = "agreeToCustomPrivacyPolicy";
    private Boolean agreeToCustomPrivacyPolicy;

    public static final String JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL = "customPrivacyPolicyUrl";
    private String customPrivacyPolicyUrl;

    public static final String JSON_PROPERTY_DEFAULT_APP = "defaultApp";
    private DefaultApp defaultApp;

    public static final String JSON_PROPERTY_EMAIL_DOMAIN_ID = "emailDomainId";
    private String emailDomainId;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_IS_DEFAULT = "isDefault";
    private Boolean isDefault;

    public static final String JSON_PROPERTY_LOCALE = "locale";
    private String locale;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_REMOVE_POWERED_BY_OKTA = "removePoweredByOkta";
    private Boolean removePoweredByOkta = false;

    public Brand() {
    }

    /*
     * @JsonCreator public Brand(
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_IS_DEFAULT) Boolean isDefault ) { this(); this.id = id; this.isDefault = isDefault; }
     */

    public Brand agreeToCustomPrivacyPolicy(Boolean agreeToCustomPrivacyPolicy) {

        this.agreeToCustomPrivacyPolicy = agreeToCustomPrivacyPolicy;
        return this;
    }

    /**
     * Consent for updating the custom privacy URL. Not required when resetting the URL.
     *
     * @return agreeToCustomPrivacyPolicy
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Consent for updating the custom privacy URL. Not required when resetting the URL.")
    @JsonProperty(JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getAgreeToCustomPrivacyPolicy() {
        return agreeToCustomPrivacyPolicy;
    }

    @JsonProperty(JSON_PROPERTY_AGREE_TO_CUSTOM_PRIVACY_POLICY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAgreeToCustomPrivacyPolicy(Boolean agreeToCustomPrivacyPolicy) {
        this.agreeToCustomPrivacyPolicy = agreeToCustomPrivacyPolicy;
    }

    public Brand customPrivacyPolicyUrl(String customPrivacyPolicyUrl) {

        this.customPrivacyPolicyUrl = customPrivacyPolicyUrl;
        return this;
    }

    /**
     * Custom privacy policy URL
     *
     * @return customPrivacyPolicyUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Custom privacy policy URL")
    @JsonProperty(JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getCustomPrivacyPolicyUrl() {
        return customPrivacyPolicyUrl;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOM_PRIVACY_POLICY_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomPrivacyPolicyUrl(String customPrivacyPolicyUrl) {
        this.customPrivacyPolicyUrl = customPrivacyPolicyUrl;
    }

    public Brand defaultApp(DefaultApp defaultApp) {

        this.defaultApp = defaultApp;
        return this;
    }

    /**
     * Get defaultApp
     *
     * @return defaultApp
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DefaultApp getDefaultApp() {
        return defaultApp;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT_APP)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefaultApp(DefaultApp defaultApp) {
        this.defaultApp = defaultApp;
    }

    public Brand emailDomainId(String emailDomainId) {

        this.emailDomainId = emailDomainId;
        return this;
    }

    /**
     * The ID of the email domain
     *
     * @return emailDomainId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID of the email domain")
    @JsonProperty(JSON_PROPERTY_EMAIL_DOMAIN_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getEmailDomainId() {
        return emailDomainId;
    }

    @JsonProperty(JSON_PROPERTY_EMAIL_DOMAIN_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEmailDomainId(String emailDomainId) {
        this.emailDomainId = emailDomainId;
    }

    /**
     * The Brand ID
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The Brand ID")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * If &#x60;true&#x60;, the Brand is used for the Okta subdomain
     *
     * @return isDefault
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "If `true`, the Brand is used for the Okta subdomain")
    @JsonProperty(JSON_PROPERTY_IS_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getIsDefault() {
        return isDefault;
    }

    public Brand locale(String locale) {

        this.locale = locale;
        return this;
    }

    /**
     * The language specified as an [IETF BCP 47 language tag](https://datatracker.ietf.org/doc/html/rfc5646)
     *
     * @return locale
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The language specified as an [IETF BCP 47 language tag](https://datatracker.ietf.org/doc/html/rfc5646)")
    @JsonProperty(JSON_PROPERTY_LOCALE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getLocale() {
        return locale;
    }

    @JsonProperty(JSON_PROPERTY_LOCALE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLocale(String locale) {
        this.locale = locale;
    }

    public Brand name(String name) {

        this.name = name;
        return this;
    }

    /**
     * The name of the Brand
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The name of the Brand")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public Brand removePoweredByOkta(Boolean removePoweredByOkta) {

        this.removePoweredByOkta = removePoweredByOkta;
        return this;
    }

    /**
     * Removes \&quot;Powered by Okta\&quot; from the sign-in page in redirect authentication deployments, and \&quot;©
     * [current year] Okta, Inc.\&quot; from the Okta End-User Dashboard
     *
     * @return removePoweredByOkta
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Removes \"Powered by Okta\" from the sign-in page in redirect authentication deployments, and \"© [current year] Okta, Inc.\" from the Okta End-User Dashboard")
    @JsonProperty(JSON_PROPERTY_REMOVE_POWERED_BY_OKTA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRemovePoweredByOkta() {
        return removePoweredByOkta;
    }

    @JsonProperty(JSON_PROPERTY_REMOVE_POWERED_BY_OKTA)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRemovePoweredByOkta(Boolean removePoweredByOkta) {
        this.removePoweredByOkta = removePoweredByOkta;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        Brand brand = (Brand) o;
        return Objects.equals(this.agreeToCustomPrivacyPolicy, brand.agreeToCustomPrivacyPolicy)
                && Objects.equals(this.customPrivacyPolicyUrl, brand.customPrivacyPolicyUrl)
                && Objects.equals(this.defaultApp, brand.defaultApp)
                && Objects.equals(this.emailDomainId, brand.emailDomainId) && Objects.equals(this.id, brand.id)
                && Objects.equals(this.isDefault, brand.isDefault) && Objects.equals(this.locale, brand.locale)
                && Objects.equals(this.name, brand.name)
                && Objects.equals(this.removePoweredByOkta, brand.removePoweredByOkta);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(agreeToCustomPrivacyPolicy, customPrivacyPolicyUrl, defaultApp, emailDomainId, id,
                isDefault, locale, name, removePoweredByOkta);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class Brand {\n");
        sb.append("    agreeToCustomPrivacyPolicy: ").append(toIndentedString(agreeToCustomPrivacyPolicy)).append("\n");
        sb.append("    customPrivacyPolicyUrl: ").append(toIndentedString(customPrivacyPolicyUrl)).append("\n");
        sb.append("    defaultApp: ").append(toIndentedString(defaultApp)).append("\n");
        sb.append("    emailDomainId: ").append(toIndentedString(emailDomainId)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    isDefault: ").append(toIndentedString(isDefault)).append("\n");
        sb.append("    locale: ").append(toIndentedString(locale)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    removePoweredByOkta: ").append(toIndentedString(removePoweredByOkta)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
